@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005, 2006, 2007 Freetalk Core Team 
+  Copyright (c) 2005-2014 Freetalk Core Team
   This file is part of GNU Freetalk.
 
   Freetalk is free software; you can redistribute it and/or modify it
@@ -20,55 +20,54 @@
 #ifndef __FREETALK_H__
 #define __FREETALK_H__
 
-#include <libintl.h>
+#ifndef _CONFIG_H
+#define _CONFIG_H
+#include "config.h"
+#endif
+
 #include <loudmouth/loudmouth.h>
 #include <time.h>
 #include "util.h"
-#include "file_transfer.h"
+#include "roster.h"
 
 #define FT_GLOBAL_EXT_DIR   DATADIR "/" PACKAGE_NAME "/extensions"
 #define FT_LOCAL_EXT_DIR    "." PACKAGE_NAME "/extensions" /* relative to $HOME */
 #define FT_CONFIG_SCM        "." PACKAGE_NAME "/" PACKAGE_NAME ".scm"
 
-#define _(String) gettext (String)
-#define gettext_noop(String) String
-#define N_(String) gettext_noop (String)
-
 enum ft_conn_state {
-  FT_DEAD = 0,
-  FT_CONN,
-  FT_AUTH
+        FT_DEAD = 0,
+        FT_CONN,
+        FT_AUTH
 };
 
 typedef struct {
-  int argc;
-  char **argv;
-  char *server;
-  char *jid_str;
-  jid_t jid;
-  char *password;
-  char *current_buddy; /* autoinsertion */
-  LmConnection *conn; /* = (LmConnection *) conn */
-  char *prompt; /* "freetalk> " */
-  GError *error;
-  char need_ssl;
-  unsigned short port;
-  char daemon;
-  char async_printf;
-  enum ft_conn_state conn_state;
-  char *status_msg;
-  GSList *roster;
-  char *script;
-  char *config_dir;
-  GSList *f_state; /* file transfer states - linked list */
-  char *download_dirname; /* default directory where all files xfered go */
-  time_t last;
-  char need_proxy;
-  char *proxyserver;
-  unsigned short proxyport;
-  char *proxyuname;
-  char *proxypasswd;
-  LmProxy *proxy;
+        int argc;
+        char **argv;
+        char *server;
+        char *jid_str;
+        jid_t jid;
+        char *password;
+        FtRosterItem *current_buddy;
+        LmConnection *conn; /* = (LmConnection *) conn */
+        char *prompt; /* "freetalk> " */
+        GError *error;
+        char need_ssl;
+        char need_tls;
+        unsigned short port;
+        char daemon;
+        char async_printf;
+        enum ft_conn_state conn_state;
+        char *status_msg;
+        GSList *roster;
+        char *script;
+        char *config_dir;
+        time_t last;
+        char need_proxy;
+        char *proxyserver;
+        unsigned short proxyport;
+        char *proxyuname;
+        char *proxypasswd;
+        LmProxy *proxy;
 } ft_state;
 
 extern ft_state state;
