@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005, 2006, 2007 Freetalk Core Team 
+  Copyright (c) 2005-2014 Freetalk Core Team
   This file is part of GNU Freetalk.
 
   Freetalk is free software; you can redistribute it and/or modify it
@@ -20,16 +20,15 @@
 #ifndef __INTERPRETER_H__
 #define __INTERPRETER_H__
 
+#ifndef _CONFIG_H
+#define _CONFIG_H
+#include "config.h"
+#endif
+
 #include <regex.h>
 
 void interpreter_init (void);
 int interpreter (char *line);
-
-static inline char * complete_none (const char *txt, int state)
-{
-  return NULL;
-}
-
 char ** ft_auto_complete (const char *txt, int start, int end);
 
 #endif /* __INTERPRETER_H__ */
